@@ -17,12 +17,12 @@
 package org.apache.commons.rng.core.source64;
 
 import org.apache.commons.rng.core.RandomAssert;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
-public class MersenneTwister64Test {
+class MersenneTwister64Test {
     @Test
-    public void testMakotoNishimura() {
+    void testMakotoNishimura() {
         final MersenneTwister64 rng = new MersenneTwister64(new long[] {0x12345L, 0x23456L, 0x34567L, 0x45678L});
 
         /*
@@ -287,11 +287,11 @@ public class MersenneTwister64Test {
     }
 
     @Test
-    public void testConstructorWithEmptySeed() {
+    void testConstructorWithEmptySeed() {
         // An empty seed is allowed
         final MersenneTwister64 rng = new MersenneTwister64(new long[0]);
         // It should be functional so check it returns different values.
-        Assert.assertNotEquals("Empty seed creates sequence with same values",
-            rng.nextLong(), rng.nextLong());
+        Assertions.assertNotEquals(rng.nextLong(), rng.nextLong(),
+            "Empty seed creates sequence with same values");
     }
 }
