@@ -16,12 +16,10 @@
  */
 package org.apache.commons.rng.sampling.distribution;
 
-import org.apache.commons.rng.RestorableUniformRandomProvider;
 import org.apache.commons.rng.UniformRandomProvider;
 import org.apache.commons.rng.sampling.RandomAssert;
-import org.apache.commons.rng.simple.RandomSource;
-import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test for the {@link RejectionInversionZipfSampler}. The tests hit edge cases for the sampler.
@@ -32,8 +30,7 @@ class RejectionInversionZipfSamplerTest {
      */
     @Test
     void testConstructorThrowsWithZeroNumberOfElements() {
-        final RestorableUniformRandomProvider rng =
-            RandomSource.SPLIT_MIX_64.create(0L);
+        final UniformRandomProvider rng = RandomAssert.seededRNG();
         final int numberOfElements = 0;
         final double exponent = 1;
         Assertions.assertThrows(IllegalArgumentException.class,
@@ -44,11 +41,10 @@ class RejectionInversionZipfSamplerTest {
      * Test the constructor with a bad exponent.
      */
     @Test
-    void testConstructorThrowsWithZeroExponent() {
-        final RestorableUniformRandomProvider rng =
-            RandomSource.SPLIT_MIX_64.create(0L);
+    void testConstructorThrowsWithNegativeExponent() {
+        final UniformRandomProvider rng = RandomAssert.seededRNG();
         final int numberOfElements = 1;
-        final double exponent = 0;
+        final double exponent = Math.nextDown(0);
         Assertions.assertThrows(IllegalArgumentException.class,
             () -> RejectionInversionZipfSampler.of(rng, numberOfElements, exponent));
     }
@@ -58,13 +54,41 @@ class RejectionInversionZipfSamplerTest {
      */
     @Test
     void testSharedStateSampler() {
-        final UniformRandomProvider rng1 = RandomSource.SPLIT_MIX_64.create(0L);
-        final UniformRandomProvider rng2 = RandomSource.SPLIT_MIX_64.create(0L);
-        final int numberOfElements = 7;
-        final double exponent = 1.23;
-        final SharedStateDiscreteSampler sampler1 =
-            RejectionInversionZipfSampler.of(rng1, numberOfElements, exponent);
+        testSharedStateSampler(7, 1.23);
+    }
+
+    /**
+     * Special case: Test the SharedStateSampler implementation with a zero exponent.
+     */
+    @Test
+    void testSharedStateSamplerWithZeroExponent() {
+        testSharedStateSampler(7, 0);
+    }
+
+    /**
+     * Test the SharedStateSampler implementation for the specified parameters.
+     *
+     * @param numberOfElements Number of elements
+     * @param exponent Exponent
+     */
+    private static void testSharedStateSampler(int numberOfElements, double exponent) {
+        final UniformRandomProvider rng1 = RandomAssert.seededRNG();
+        final UniformRandomProvider rng2 = RandomAssert.seededRNG();
+        // Use instance constructor not factory constructor to exercise 1.X public API
+        final RejectionInversionZipfSampler sampler1 =
+            new RejectionInversionZipfSampler(rng1, numberOfElements, exponent);
         final SharedStateDiscreteSampler sampler2 = sampler1.withUniformRandomProvider(rng2);
         RandomAssert.assertProduceSameSequence(sampler1, sampler2);
     }
+
+    /**
+     * Test the toString method. This is added to ensure coverage as the factory constructor
+     * used in other tests does not create an instance of the wrapper class.
+     */
+    @Test
+    void testToString() {
+        final UniformRandomProvider rng = RandomAssert.seededRNG();
+        Assertions.assertTrue(new RejectionInversionZipfSampler(rng, 10, 2.0).toString()
+                .toLowerCase().contains("zipf"));
+    }
 }
