@@ -16,24 +16,40 @@
  */
 package org.apache.commons.rng.simple.internal;
 
+import java.util.stream.IntStream;
 import org.junit.jupiter.api.Assertions;
-import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.MethodSource;
 
 /**
  * Tests for the {@link IntArray2LongArray} converter.
  */
 class IntArray2LongArrayTest {
-    @Test
-    void testSeedSizeIsMultipleOfLongSize() {
-        final int[] seed = new int[12];
-        final long[] out = new IntArray2LongArray().convert(seed);
-        Assertions.assertEquals(6, out.length);
+    /**
+     * Gets the lengths for the int[] seeds to convert.
+     *
+     * @return the lengths
+     */
+    static IntStream getLengths() {
+        return IntStream.rangeClosed(0, (Long.BYTES / Integer.BYTES) * 2);
     }
 
-    @Test
-    void testSeedSizeIsNotMultipleOfLongSize() {
-        final int[] seed = new int[13];
+    /**
+     * Gets the expected output length.
+     *
+     * @param ints Number of ints
+     * @return the output length
+     */
+    private static int getOutputLength(int ints) {
+        return (int) Math.ceil((double) ints / 2);
+    }
+
+    @ParameterizedTest
+    @MethodSource(value = {"getLengths"})
+    void testSeedSizeIsMultipleOfIntSize(int ints) {
+        final int[] seed = new int[ints];
+
         final long[] out = new IntArray2LongArray().convert(seed);
-        Assertions.assertEquals(7, out.length);
+        Assertions.assertEquals(getOutputLength(ints), out.length);
     }
 }
